@@ -23,15 +23,8 @@
 #'
 #' res <- tomek(circle_numeric, var = "class")
 tomek <- function(df, var) {
-  if (length(var) != 1) {
-    rlang::abort("Please select a single factor variable for `var`.")
-  }
-
-  var <- rlang::arg_match(var, colnames(df))
-
-  if (!(is.factor(df[[var]]) | is.character(df[[var]]))) {
-    rlang::abort(glue("`{var}` should be a factor or character variable."))
-  }
+  check_data_frame(df)
+  check_var(var, df)
 
   predictors <- setdiff(colnames(df), var)
 
